#
# spec file for package python-PyX
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%bcond_without  test
%{?sle15_python_module_pythons}
Name:           python-PyX
Version:        0.16
Release:        3.0.2.1.sr20250402
Summary:        Python package for the generation of PostScript, PDF, and SVG files
License:        GPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://pyx-project.org/
Source:         https://github.com/pyx-project/pyx/archive/%{version}.tar.gz#/PyX-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testfixtures}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  texlive-latex-bin-bin
BuildRequires:  texlive-tex-bin
BuildRequires:  texlive-texware-bin
Requires:       texlive-latex-bin-bin
Requires:       texlive-tex-bin
Requires:       texlive-texware-bin
Obsoletes:      python-pyx < %{version}
Provides:       python-pyx = %{version}
BuildArch:      noarch
%python_subpackages

%description
PyX is a Python package for the creation of PostScript, PDF, and SVG files. It
combines an abstraction of the PostScript drawing model with a TeX/LaTeX
interface. Complex tasks like 2d and 3d plots in publication-ready quality are
built out of these primitives.

%prep
%setup -q -n pyx-%{version}
# ignore unrelated warning "ignoring special 'header=l3backend-dvips.pro'"
sed -i 's/l.check/l.check_present/' test/unit/test_texmessageparser.py

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand # Cleanups
chmod -x %{buildroot}%{$python_sitelib}/pyx/data/lfs/createlfs.py
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest test/unit

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGES README.md
%{python_sitelib}/pyx/
%{python_sitelib}/[Pp]y[Xx]-%{version}.dist-info

%changelog
* Tue Apr 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Thu Mar 21 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Fri Sep  8 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.16:
  * Enable a shortcut for accessing graph-component attributes,
    simplifying the modification of default components.
  * Small improvements and several bug fixes, especially for text
    alignment with TeX Live 2020.
- Rename source tarball to PyX-%%{version}.tar.gz.
- Use pyproject macros to build; add BuildRequires: python-pip,
  python-wheel.
* Fri May  7 2021 Ben Greiner <code@bnavigator.de>
- Ignore unrelated warning during tests introduced by l3backend
- Specify runtime requirements
- Fix provides/obsoletes rename for flavors
* Wed Jul 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.15:
  * This release introduces a new text engine UnicodeEngine, which enables
    simple typesetting with Type1 fonts without using TeX/LaTeX. The graph
    axis texters have been adjusted to work on the UnicodeEngine, as well.
    The exponential and mixed graph axis texters have been merged into the
    new default texter.
  * PyX' home has been moved to https://pyx-project.org. The source code
    repository has been converted to git and is now hosted at
    https://github.com/pyx-project/pyx.
- Switch to github tarball and enable tests
* Thu Sep  7 2017 toddrme2178@gmail.com
- Update to version 0.14.1
- Implement single-spec version, python3-only since this release
  only supports python 3.
- Rename to python-PyX to follow python-packaging guidelines.
* Sun Jul 27 2014 badshah400@gmail.com
- Update to version 0.12.1:
  - Lots of changes since previously packaged version, see
    /usr/share/doc/packages/python-pyx/CHANGES for a full list
- Packaging changes:
  - Remove spurious executable permissions and shebangs wherever
    needed to avoid rpmlint warnings
  - No longer use deprecated "--record-rpm"; use %%{python_sitelib}
    instead
  - Drop patches that no longer apply
    + python-pyx-no_root-0.8.1.patch
    + PyX-0.9-pyxrcdir.patch (no more /etc/pyxrc file)
  - Specfile cleanups
    + Remove empty %%clean section
    + Use full source URL for Source tag
    + License tag updated to spdx norms
    + export CFLAGS="$RPM_OPT_FLAGS" no more required
    + No longer required to run sed over installed files
    + List of Authors removed, see packaged AUTHORS file instead.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Aug 12 2009 matejcik@suse.cz
- build as noarch on newer distros
* Fri Apr  4 2008 matejcik@suse.cz
- update to 0.10
  * support for parallel/central projection 3D plotting
  * new styles, examples, bugfixes
* Thu Aug 30 2007 jmatejek@suse.cz
- added 'pyxrcdir' variable to config, import works again
  (#305304)
* Fri Apr 20 2007 aj@suse.de
- Cleanup BuildRequires.
* Thu Oct 19 2006 jmatejek@suse.cz
- update to 0.9
- new set of deformers
- many new examples
- module for handling Type1 fonts
- support for transparency in PDF output
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 19 2005 matejcik@suse.cz
- update to 0.8.1
- fixed no-root patch for new version
* Wed Mar 16 2005 mcihar@suse.cz
- mark config file as config
* Thu Feb 10 2005 mcihar@suse.cz
- update to 0.7.1
* Wed Aug  4 2004 mcihar@suse.cz
- update to 0.6.3
- use %%py_requires
* Fri Jan 30 2004 mcihar@suse.cz
- update to 0.5.1
* Thu Oct 30 2003 mcihar@suse.cz
- updated to 0.4.1
- no root for build
* Mon Jun 16 2003 mcihar@suse.cz
- use record-rpm
* Mon May 12 2003 mcihar@suse.cz
- use versioned dependency on python
* Tue May  6 2003 mcihar@suse.cz
- initial version
